pub enum AttDefault {
Required,
Implied,
Fixed(String),
Default(String),
}Expand description
XML 1.0  3.3.2 default declarations.
Variants
Required
#REQUIRED
Implied
#IMPLIED
Fixed(String)
#FIXED "value" — attribute must equal value if present.
Default(String)
Literal default value — supplied if the attribute is absent from the document body. v0.1 doesn’t perform defaulting at parse time, so the validator just ignores this and accepts either presence or absence.