decode_html_input

Function decode_html_input 

pub fn decode_html_input<'a>(
    bytes: &'a [u8],
    opts: &HtmlParseOptions,
) -> Result<(Cow<'a, [u8]>, Encoding)>
Sniff + transcode in one step. Returns UTF-8 bytes plus the encoding that was used so the caller can record it on the resulting Document.