pub fn first_atomic_key<I: DocIndexLike>(v: &Value, idx: &I) -> ValueExpand description
Reduce a value to the single atomic value usable as a map key (XPTY0004 if not a singleton atomic; lenient — first item, nodes contribute their string value).
pub fn first_atomic_key<I: DocIndexLike>(v: &Value, idx: &I) -> ValueReduce a value to the single atomic value usable as a map key (XPTY0004 if not a singleton atomic; lenient — first item, nodes contribute their string value).